package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.28.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.28.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````(`/@`!````\"5```````!``````````&#`````
M`````````$``.``+`$``'``;``8````$````0`````````!``$```````$``
M0```````:`(```````!H`@````````@``````````P````0```"H`@``````
M`*@"0```````J`)````````<`````````!P``````````0`````````!````
M!`````````````````!``````````$```````$`:````````0!H`````````
M$`````````$````%`````"``````````($`````````@0```````;3L`````
M``!M.P`````````0`````````0````0`````8`````````!@0````````&!`
M``````"X0P```````+A#`````````!`````````!````!@```/"M````````
M\+U```````#PO4```````"@$````````N!0`````````$`````````(````&
M`````*X`````````OD````````"^0```````\`$```````#P`0````````@`
M````````!`````0```#$`@```````,0"0```````Q`)```````!$````````
M`$0`````````!`````````!0Y71D!````(B<````````B)Q```````"(G$``
M`````/P`````````_``````````$`````````%'E=&0&````````````````
M`````````````````````````````````````````!``````````4N5T9`0`
M``#PK0```````/"]0```````\+U````````0`@```````!`"`````````0``
M```````O;&EB-C0O;&0M;&EN=7@M>#@V+38T+G-O+C(`!````!`````!````
M1TY5```````#`````@`````````$````%`````,```!'3E4``/E15?9K4^7&
M;5A(<;^?8"E!W,%#````/0````0````(````(!P0``5`!(8H`D`$D(8!C,(I
M`"!)(`0+N*(X1;H$`@H`````/0```#X```````````````````!`````00``
M``````!"````0P````````````````````````!$````10```$8`````````
M`````$<`````````20```$H`````````2P```$P```!.````3P```%````!2
M``````````````!3`````````%0``````````````%4```!6````````````
M``!8````60``````````````6@``````````````6P```%P```!=````````
M``````!>`````````%\`````````````````````````````````````````
M80```&(`````````"XH05\C5LG&CX/M)^Z%L8#GRBQQOQ=\?K4OCP&L:GE#%
MB060>_!*:WZIG)OKT^\.S]Y'+0T4XIX5C"7,5J2;EKF-\0XS8MOMLP&+;^)'
MQ@';S>.>Q;F<0,/E/RQ#^M>'+\6;MJ;=HVN)!W#3#3J7"X?YG(%K"4/6:W^:
M?$-%U>PA_^0.U634?."G`@J[XY)\9Z_,9MEQ6!P`````````````````````
M````````````````^````!(`````````````````````````H@$``!(`````
M````````````````````&`(``!(`````````````````````````]@$``!(`
M````````````````````````'P(``!(`````````````````````````JP(`
M`!(`````````````````````````9@$``!(`````````````````````````
M-`(``!(`````````````````````````DP(``!(`````````````````````
M````BP(``!(`````````````````````````Q````!(`````````````````
M````````.`,``!(`````````````````````````\P```!(`````````````
M````````````5P(``!(`````````````````````````20(``!(`````````
M````````````````!P(``!(`````````````````````````I`(``!(`````
M````````````````````M`(``!(`````````````````````````,P$``!(`
M````````````````````````5````!(`````````````````````````=`$`
M`!(`````````````````````````Z````!(`````````````````````````
MSP$``!(`````````````````````````_@$``!(`````````````````````
M````WP$``!(`````````````````````````$`$``!(`````````````````
M````````+0(``!(`````````````````````````G0$``!(`````````````
M````````````Z0(``!(`````````````````````````X@(``!(`````````
M````````````````M````!(`````````````````````````$0```"``````
M````````````````````:P(``!(`````````````````````````>````!(`
M````````````````````````NP$``!(`````````````````````````'`$`
M`!(`````````````````````````6@$``!(`````````````````````````
MTP```!(`````````````````````````(````!(`````````````````````
M````3`$``!(`````````````````````````*P```!(`````````````````
M````````<@(``!(`````````````````````````J0```!(`````````````
M````````````AP```!(`````````````````````````)0(``!(`````````
M````````````````E@$``!(`````````````````````````TP(``!(`````
M````````````````````NP(``!(`````````````````````````1@```!(`
M````````````````````````VP(``!(`````````````````````````0@(`
M`!(`````````````````````````-P```!(`````````````````````````
M;P```!(`````````````````````````@`(``!(`````````````````````
M````\0$``!(`````````````````````````LP$``!(`````````````````
M````````70(``!(`````````````````````````.P(``!(`````````````
M````````````4`(``!(`````````````````````````Q0(``!(`````````
M````````````````8@```!$`&``HPD````````$`````````_0```!(```"0
M(D``````````````````U@,``!(`#0"@,4```````+(!````````#@0``!(`
M#0``-$```````-$`````````G0(``!$`&`!@PD````````@`````````00,`
M`!(`#0`P0$```````'4`````````D@,``!$`#P``8$````````0`````````
MXP,``!(`#0#P6$```````/L!````````_`(``"$`&`!`PD````````@`````
M````(P$``!(```"P($``````````````````)@,``!(`#0#@,T```````!T`
M````````#P,``!(`#@!D6T``````````````````;0,``!(`#0#@-$``````
M`($'````````!0,``!(`#0!@6T````````$`````````+@0``!(`#0#05D``
M`````%0`````````00$``!$`&``@PD````````0`````````,00``!(`"P``
M($``````````````````BP,``!(`#0#P)4```````"L`````````(`0``!(`
M#0!@,T```````'(`````````5`,``!(`#0"@,$```````"D`````````MP,`
M`!(`#0``6T```````%T`````````^P(``!$`&`!`PD````````@`````````
M^0,``!(`#0!0+4```````"H`````````>@,``!(`#0`P5T```````+0!````
M````%0,``!(`#0"0+D````````4`````````_0(``"$`&`!`PD````````@`
M````````QP,``!$`%P`0PD````````@`````````AP,``"``%P``PD``````
M````````````F````!(```!`(T``````````````````A0,``!``%P``PD``
M````````````````]@(``!(`#0``)$```````.P!````````30,``!``%P`8
MPD```````````````````00``!(`#0"@+D```````/\!````````-P0``!(`
M#0!P/$```````+<#````````H0,``!(`#0#0+4```````+0`````````T0,`
M`!``&`"HTD``````````````````80,``!(`#0#0,$```````,,`````````
M[0,``!``&``8PD```````````````````&QI8G!E<FPM-2XR."YS;P!?7V=M
M;VY?<W1A<G1?7P!097)L7VYE=UA3`%!E<FQ?;6=?<V5T`%!E<FQ?<W9?<V5T
M<'9N`%!E<FQ?879?9F5T8V@`4&5R;%]S=E]S971P=@!03%]D;U]U;F1U;7``
M<&5R;%]R=6X`4&5R;%]S>7-?:6YI=#,`4&5R;%]N97=84U]F;&%G<P!097)L
M7V%T9F]R:U]L;V-K`'!E<FQ?<&%R<V4`4&5R;%]G=E]F971C:'!V`'!E<FQ?
M8V]N<W1R=6-T`%!E<FQ?8W)O86M?;F]C;VYT97AT`'!E<FQ?86QL;V,`<&5R
M;%]F<F5E`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-A9F5S>7-M86QL;V,`
M8F]O=%]$>6YA3&]A9&5R`'!E<FQ?9&5S=')U8W0`4$Q?=&AR7VME>0!097)L
M7W-Y<U]T97)M`%!E<FQ?9V5T7W-V`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R
M<'9?9FQA9W,`;&EB<'1H<F5A9"YS;RXP`&]P96XV-`!R96%D`%]?97)R;F]?
M;&]C871I;VX`;'-E96LV-`!P=&AR96%D7V=E='-P96-I9FEC`&-L;W-E`&QI
M8F,N<V\N-@!?7W)E9VES=&5R7V%T9F]R:P!E>&ET`'-T<FYC;7``8VQO<V5D
M:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!M96UC
M:'(`9V5T<&ED`'-T<F1U<`!S=')T;VL`<W1R;&5N`'-T<G-T<@!R;61I<@!?
M7V9P<FEN=&9?8VAK`&UE;6-P>0!?7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`
M;W!E;F1I<@!?7WAS=&%T-C0`<W1D97)R`&=E='5I9`!R96%D;&EN:P!S=')C
M:'(`<F5A9&1I<C8T`%]?<W!R:6YT9E]C:&L`;65M;6]V90!A8V-E<W,`<W1R
M8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?96YV:7)O;@!?7VQI8F-?8W-U7V9I
M;FD`<&%R7V-U<G)E;G1?97AE8P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I
M9`!P87)?8VQE86YU<`!?961A=&$`<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE
M`'!A<E]M:W1M<&1I<@!S:&%?=7!D871E`%]?9&%T85]S=&%R=`!?24]?<W1D
M:6Y?=7-E9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`7U]L:6)C7V-S=5]I;FET
M`&UY7W!A<E]P;`!?96YD`'!A<E]I;FET7V5N=@!S:&%?9FEN86P`7U]B<W-?
M<W1A<G0`>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`
M<&%R7V5N=E]C;&5A;@!S:&%?:6YI=`!84U]);G1E<FYA;'-?4$%27T)/3U0`
M1TQ)0D-?,BXR+C4`1TQ)0D-?,BXS+C0`1TQ)0D-?,BXQ-`!'3$E"0U\R+C,N
M,@!'3$E"0U\R+C0````"``,``@`"``(``@````(``@`"`````@````(``@`$
M``(``@````````````,``@`%`````@`#``(``@``````!@````,``@``````
M````````!P```````@`#``(``@````(``@```````@`"``,`!P`"``(`!P``
M`````0`!``(``0`!``$``@````$``0`!``$``0````$``0`!``$``0`"``$`
M`0`!``(``0`!`````0`!``$``0`!``$``0`!``$```````$``0"&`0``$```
M`"````!U&FD)```#`$T$`````````0`%`-4!```0`````````'09:0D```<`
M600``!````"4D98&```&`&4$```0````<AEI"0``!0!P!```$````!1I:0T`
M``0`?`0``!````!U&FD)```"`$T$````````\+]````````&````'0``````
M````````^+]````````&````(```````````````(,)````````%````3```
M````````````*,)````````%````/0``````````````0,)````````%````
M4@``````````````8,)````````%````00``````````````&,!````````'
M`````0``````````````(,!````````'`````@``````````````*,!`````
M```'`````P``````````````,,!````````'````!```````````````.,!`
M```````'````!0``````````````0,!````````'````!@``````````````
M2,!````````'````!P``````````````4,!````````'````"```````````
M````6,!````````'````1@``````````````8,!````````'````"0``````
M````````:,!````````'````"@``````````````<,!````````'````"P``
M````````````>,!````````'````#```````````````@,!````````'````
M#0``````````````B,!````````'````#@``````````````D,!````````'
M````#P``````````````F,!````````'````$```````````````H,!`````
M```'````$0``````````````J,!````````'````$@``````````````L,!`
M```````'````$P``````````````N,!````````'````%```````````````
MP,!````````'````%0``````````````R,!````````'````%@``````````
M````T,!````````'````%P``````````````V,!````````'````&```````
M````````X,!````````'````&0``````````````Z,!````````'````&@``
M````````````\,!````````'````&P``````````````^,!````````'````
M'````````````````,%````````'````'@``````````````",%````````'
M````'P``````````````$,%````````'````(0``````````````&,%`````
M```'````(@``````````````(,%````````'````(P``````````````*,%`
M```````'````)```````````````,,%````````'````)0``````````````
M.,%````````'````)@``````````````0,%````````'````)P``````````
M````2,%````````'````/@``````````````4,%````````'````*```````
M````````6,%````````'````*0``````````````8,%````````'````*@``
M````````````:,%````````'````*P``````````````<,%````````'````
M+```````````````>,%````````'````+0``````````````@,%````````'
M````+@``````````````B,%````````'````+P``````````````D,%`````
M```'````,```````````````F,%````````'````,0``````````````H,%`
M```````'````60``````````````J,%````````'````,@``````````````
ML,%````````'````,P``````````````N,%````````'````-```````````
M````P,%````````'````-0``````````````R,%````````'````-@``````
M````````T,%````````'````-P``````````````V,%````````'````.```
M````````````X,%````````'````.0``````````````Z,%````````'````
M.@``````````````\,%````````'````.P``````````````^,%````````'
M````/```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!(@^P(2(L%[9\``$B%P'0"_]!(@\0(PP```````````/\UXI\``/\EY)\`
M``\?0`#_)>*?``!H`````.G@_____R7:GP``:`$```#IT/____\ETI\``&@"
M````Z<#_____)<J?``!H`P```.FP_____R7"GP``:`0```#IH/____\ENI\`
M`&@%````Z9#_____);*?``!H!@```.F`_____R6JGP``:`<```#I</____\E
MHI\``&@(````Z6#_____)9J?``!H"0```.E0_____R62GP``:`H```#I0/__
M__\EBI\``&@+````Z3#_____)8*?``!H#````.D@_____R5ZGP``:`T```#I
M$/____\E<I\``&@.````Z0#_____)6J?``!H#P```.GP_O___R5BGP``:!``
M``#IX/[___\E6I\``&@1````Z=#^____)5*?``!H$@```.G`_O___R5*GP``
M:!,```#IL/[___\E0I\``&@4````Z:#^____)3J?``!H%0```.F0_O___R4R
MGP``:!8```#I@/[___\E*I\``&@7````Z7#^____)2*?``!H&````.E@_O__
M_R4:GP``:!D```#I4/[___\E$I\``&@:````Z4#^____)0J?``!H&P```.DP
M_O___R4"GP``:!P```#I(/[___\E^IX``&@=````Z1#^____)?*>``!H'@``
M`.D`_O___R7JG@``:!\```#I\/W___\EXIX``&@@````Z>#]____)=J>``!H
M(0```.G0_?___R72G@``:"(```#IP/W___\ERIX``&@C````Z;#]____)<*>
M``!H)````.F@_?___R6ZG@``:"4```#ID/W___\ELIX``&@F````Z8#]____
M):J>``!H)P```.EP_?___R6BG@``:"@```#I8/W___\EFIX``&@I````Z5#]
M____)9*>``!H*@```.E`_?___R6*G@``:"L```#I,/W___\E@IX``&@L````
MZ2#]____)7J>``!H+0```.D0_?___R5RG@``:"X```#I`/W___\E:IX``&@O
M````Z?#\____)6*>``!H,````.G@_/___R5:G@``:#$```#IT/S___\E4IX`
M`&@R````Z<#\____)4J>``!H,P```.FP_/___R5"G@``:#0```#IH/S___\E
M.IX``&@U````Z9#\____)3*>``!H-@```.F`_/___R4JG@``:#<```#I</S_
M__\E(IX``&@X````Z6#\____)1J>``!H.0```.E0_/___R42G@``:#H```#I
M0/S___\E"IX``&@[````Z3#\____)0*>``!H/````.D@_/__4TB#[#")?"0<
M2(U\)!Q(B70D$$B-="002(E4)`A(C50D"&1(BP0E*````$B)1"0H,<#H^?W_
M_[J0(D``OT`C0`!(B=;HIS8``(`]V)T```!U+^@Y_?__2(D%0JX``$B%P`^$
M>P$``$B)Q^AQ_/__BSVKG0``Z,;]___&@-$)````BSV9G0``Z+3]__^+/8Z=
M``"`B#H$```"Z*+]__^`B#H$```!BT0D'(UX!4AC_TC!YP/H&/W__TR+3"00
MQP7)K0``!````$B)!;JM``!)BQ%(QT`(X&%``$C'0!CC84``2(D02(L5)9T`
M`$B)4!"+5"0<@_H!?BB-2OZ^`0```$B#P0(/'T``38L$\8U^!$B#Q@%(8_],
MB43X^$@Y\77HC4H$13'`@\(#OH`M0`!(8\E(BSUHK0``2,=$R/@`````2(G!
MZ(?]__^)PX7`=$M(BSU*K0``Z`7\__\QP$B-="0DO[!@0`#H9`$``$B%P'0Y
M2(L]**T``.B#^___Z![]__^)V$B+7"0H9$@S'"4H````=4E(@\0P6\-(BSW_
MK```Z-K]__^)P^NE2(L]YZP``$B%_W0'Z'4:``#KM+]E8$``2(UT)"3H!`$`
M`$B)QTB)!<*L``!(A<!TENO9Z$[[__^_`0```.BT_?__#Q]``#'M28G17DB)
MXDB#Y/!05$G'P&!;0`!(Q\$`6T``2,?'`"1``/\5UID``/0/'T0``+@8PD``
M2#T8PD``=!.X`````$B%P'0)OQC"0`#_X&:0PV9F+@\?A```````#Q]``+X8
MPD``2('N&,)``$C!_@-(B?!(P>@_2`'&2-'^=!&X`````$B%P'0'OQC"0`#_
MX,-F9BX/'X0```````\?0`"`/=&;````=1=52(GEZ'[____&!;^;```!7<,/
M'T0``,-F9BX/'X0```````\?0`#KCF8N#Q^$```````/'T``05=!5D%50515
M4TB#[`A(A?\/A+$```!,BSU2FP``387_#X2A````#[8'A,!T!#P]=5Y%,>1)
MBQ](A=MT.4F)]4F)_DUCY$R)_0\?@`````!,B>),B?9(B=_H,OG__X7`=0="
M@#PC/71'2(/%"$B+70!(A=MUVDB#Q`A(B=A;74%<05U!7D%?PP\?A```````
M28G\28/$`4$/M@0DA,!T!#P]=>]!*?SKC`\?@`````!,*?U*C5PC`4C!_0-!
MB6T`Z[1F#Q]$```QV^NJ#Q]``%-(B?M(@^P09$B+!"4H````2(E$)`@QP`\?
MA```````,<!(C70D!$B)W^@!____2(7`=#1(8U0D!$B+!6":``!(C0302(M0
M"$B)$$B%TG302(/`"$B+4`A(B1!(A=)U\.N^9@\?1```2(M$)`AD2#,$)2@`
M``!U!DB#Q!!;P^@-^?__9F8N#Q^$``````!FD$%7059!54%454B)]5-(B?M(
M@^PH9$B+!"4H````2(E$)!@QP#'`@#X]#Y3`2`'%2(GOZ+GX__](C70D%$B)
MWTF)Q#'`Z%?^__](A<`/A`X!``!(B<=)B<7HD_C__TPYX`^#V@```$QC="04
M2<'F`P^V`X3`#X2N`0``/#T/A*8!``!(B=@/'P!(@\`!#[80A-)T!8#Z/77P
M2"G82)A*C7P@`DP#-6>9``#H<OG__TF)!DB%P`^$@@$``$B+!4^9``!(8U0D
M%$B-2P%(BQ30#[8#B`(\/70?A,!U">L9#Q\`/#UT$DB#P0$/MD'_2(/"`8@"
MA,!UZL8"/3'`#Q]$```/MDP%`(A,`@%(@\`!A,EU[S'`2(M<)!AD2#,<)2@`
M```/A1\!``!(@\0H6UU!7$%=05Y!7\-F+@\?A```````,<!F#Q]$```/ME0%
M`$&(5`4`2(/``832=>[KM0\?0`!,BSVIF```28,_``^$O@```$R)^#'2ZPL/
M'X0``````$2)ZDB#P`A$C6H!2(,X`'7OC7(#2&/V2,'F`XL%KZ@``(7`=5O'
M!:&H```!````2(GWZ&GX__](A<`/A'P```!-8\5,B?Y(B<=.C33%`````$R)
M1"0(3(GRZ`+Y__],BT0D"$B)!2:8``!(B<%*QT3!"`````!$B6PD%.EO_O__
M3(G_Z+CX__](B<%(B07^EP``2(7`="5-8\5.C33%`````.O)#Q]``#'`Z6[^
M__^^$````$4Q[>E?____N/_____IS?[__^BU]O__#Q]$``!!54%455-(@>RH
M````9$B+!"4H````2(F$))@````QP$B%_W0(@#\`2(G]=2M(BX0DF````&1(
M,P0E*`````^%$P$``$B!Q*@```!;74%<05W#9@\?1```Z//U__])B<1(A<!T
MR$R)Y^@S^/__2(7`#X3"````2(U8$[\18$``N0(```!(B=[SI@^7P!P`A,!T
MT[\08$``N0,```!(B=[SI@^7P!P`A,!TNTB)[^CN]?__2(G?28G%Z./U__]!
MC7P%`DAC_^@&]___28G928GHN1-@0`!)B<5(B<>^`0```#'`2,?"_____^B"
M^/__OP$```!(B>),B>[H0O7__TR)[X/X_W00BT0D&"4`\```/0!```!T.NBU
M]/__3(GOZ(WT__],B>?H=??__TB%P`^%0O___P\?0`!,B>?H\/7__TB)[^A(
M]?__Z>#^__\/'P#HJ_[__^O$Z%3U__\/'T``4TB)_DB)^[\!````2('LH```
M`&1(BP0E*````$B)A"28````,<!(B>+H@O?__X7`=3:+5"08@>(`\```@?H`
M0```=`B!^@"@``!U'KX"````2(G?Z!?W__^%P`^4P`^VP.L'#Q]$```QP$B+
MC"28````9$@S#"4H````=0E(@<2@````6\/HQ?3__P\?1```056Z_P\``$F)
M]4%454B)_;\98$``4TB![!@0``!D2(L$)2@```!(B80D"!```#'`2(GFZ-CS
M__^%P'YTC5#_1(LE:I4``$ACVH`\'`!U6872=&1(B=J^+P```$B)Y^@-]?__
M2(7`=$]$B>?H8/7__TB)V4B)XDB)[DB)Q^A_]O__2(N$)`@0``!D2#,$)2@`
M``!U.TB!Q!@0``!;74%<05W#9@\?1```2&/8ZZ8/'P!$BR7YE```1(GGZ!'U
M__],B>I(B>Y(B<?H,_3__^NRZ.SS__]F9BX/'X0``````)!(@^P(BSW&E```
MZ.'T__^Y$&)``+JP($``OBA@0`!(B<=(@\0(Z0;U__]F#Q]$``!(@^P(BSV6
ME```Z+'T__](B<?HN?___XL]@Y0``.B>]/__0;B]84``13')NG`\0`!,B<&^
M1&!``$B)QTB#Q`CI'/7__V9F+@\?A```````D%-(@>P@(```9$B+!"4H````
M2(F$)!@@```QP.BP\O__N5E@0`!!N21@0`!(B>=!B<"Z`1```+X!````,<#H
MWO7__[H`$```2(VT)!`0``!(B>?H6?+__S')A<!X,XUX`4B)PTAC_^@5]/__
M2(G!2(7`=!U(8]M(C;0D$!```$B)QTB)VNC'\___Q@08`$B)P4B+E"08(```
M9$@S%"4H````2(G(=0E(@<0@(```6\/HK/+__V9F+@\?A```````D.D[____
M9F8N#Q^$``````!!5D%528GU05152(G]OV5@0`!32('LL!```&1(BP0E*```
M`$B)A"2H$```,<!(C70D#.CY]___OB\```!(B>](B</H:?+__TB%P'0\2(GN
MOVY@0``QP.@U^?__2(GH2(N,)*@0``!D2#,,)2@````/A84!``!(@<2P$```
M6UU!7$%=05[##Q\`2(GOZ/#Q__^^>V!``$R)[T&)Q.@@]/__28G&2(7`=*1!
M@\0!08`^`$&]$6!```^$T0````\?0`!(A=MT$TR)]DB)W^B0\O__A<`/A),`
M``!,B??HH/'__XG"2)A!@'P&_R]U%P\?0`"#Z@%(8\)!@'P&_R]!Q@0&`'3M
M1`'B@?K_#P``#X\Z____2(/L"+ES84``38GP,<!50;E]8$``N@`0``"^`0``
M`$B-O"2P````Z!+T__](C50D(+\!````2(VT)+````#HR_#__UI9A<!U$(M$
M)"@E`/```#T`@```=%6^>V!``#'_Z$GS__])B<9(A<`/A,G^__]!@#X`#X4S
M____2(7;=!ZY`@```$B)WDR)[_.F#Y?`'`"$P'3##Q^$``````!!OA%@0`"Z
M`0```.E#____O@$```!(C;PDH````.C>\O__A<!UE4B-M"2@````OVY@0`#H
MJ/?__TB-O"2@````Z#OS___I9/[__^B1\/__D`^V%TB)^(32=!YF#Q]$``!(
M@\<!@/HO#[872`]$QX32=>[##Q]$``###Q^``````$B%_P^$GP```(`_``^$
ME@```%-(B?OH-?#__TB-5`/_2#G3<A3K)V8/'X0``````$B#Z@%(.=-T&H`Z
M+W3RZP6`.B]T*$B#Z@%(.=-R\D@YTW4:@#HO=&"_?6!``%OIG?+__P\?1```
M@#HO=0E(@^H!2#G3<O)(*=HQP$B-2@)(@?D`$```=QM(@\(!N0`0``!(B=Z_
M@,)``.A2\?__N(#"0`!;PP\?`+\18$``Z4[R__]F#Q]$``"_$6!``%OI/?+_
M_V9F+@\?A```````9I!(@^Q(\P]O!3PP``"_?V!``/,/;PT_,```9$B+!"4H
M````2(E$)#@QP`^W!3@P```/*40D$&:)1"0P,<`/*4PD(.BZ]?__,<"_B&!`
M`.BN]?__,<"_D&!``.BB]?__,<"_F6!``.B6]?__,<"_H&!``.B*]?__,<"_
ML&!``.A^]?__,<"_96!``.AR]?__,<"_O&!``.AF]?__,<"_QF!``.A:]?__
M,<"_T&!``.A.]?__,<"_;F!``.A"]?__,<!(C70D#+_:8$``Z&'T__](A<!T
M#TB)QK_&8$``,<#HK?7__S'`2(UT)`R_ZV!``.@\]/__2(7`=`](B<:__6!`
M`#'`Z(CU__\QP$B-="0,OPAA0`#H%_3__TB%P'0Z2(G&OV5@0``QP.AC]?__
M,<"^-&%``+^@8$``Z%+U__](BT0D.&1(,P0E*````'5?2(/$2,,/'T0``#'`
M2(UT)`R_&&%``.C'\___2(7`=!)(B<:_O&!``#'`Z!/U___KKI!(C70D(;\I
M84``N0H```#SI@^7P!P`A,!UDTB-="0KO[Q@0``QP.CE]/__ZX#HWNW__V9F
M+@\?A```````#Q\`2(/L&&1(BP0E*````$B)1"0(,<"+!8Z.``"#^/]T&4B+
M="0(9$@S-"4H````=3Y(@\08PP\?0`!(C70D!+^\8$``,<#H)_/__TB)PC'`
M2(72=!(/MA*`^C`/E<$QP(32#Y7`(<B)!3V.``#KLNA>[?__9F8N#Q^$````
M```/'P!(@^P(Z%?M__^)Q^@`[?__2(7`=`-(BP!(@\0(PP\?`$%454B)_;\V
M84``4TB#[!!D2(L$)2@```!(B40D"#'`2(UT)`3HIO+__TB)[DB%P'0(@#@`
M2(G#=2:_-F%``#'`Z.KS__](BT0D"&1(,P0E*````'5V2(/$$%M=05S#D$B)
MQ^AX[___2(7`==E(B>_HJ^S__TB)WTF)Q.B@[/__28U\!`+HQNW__TB#[`A)
MB>BY<V%``%-(Q\+_____2(G'28G$0;E[8$``O@$````QP.@Z[___3(GFOS9A
M0``QP.AK\___6%KI>O___^A?[/__9F8N#Q^$```````/'T``05=!5D%528G]
MOV5@0`!!5%532('LB($``&1(BP0E*````$B)A"1X@0``,<!(C70D'$C'1"0@
M4F%``$C'1"0H$6!``$C'1"0P`````$C'1"1@_6!``$C'1"1H]F!``$C'1"1P
M5V%``$C'1"1X$V%``$C'A"2`````7V%``$C'A"2(`````````$C'1"1`1F%`
M`$C'1"1(8V%``$C'1"10`````.A(\?__2(7`=`F`.``/A:($```QP.A#_O__
M2(G#2(7`#X07!```2(G?Z&_K__](C7P``>B5[/__@#L`28G$=#5,B>5)Q\;_
M____#Q\`1`^V`TB)[S'`N6QA0`!,B?*^`0```$B#PP%(@\4"Z/WM__^`.P!U
MV$B-7"1HO_U@0`#K%0\?0`!(@\,(2(M[^$B%_P^$AP$``$B-="0<,<#HJ_#_
M_TB)Q4B%P'3;@#@`=-9(B<?HIO7__X7`=,I(B>_HBNW__TB)PTB%P`^$3@$`
M`&8/'T0``$B)V8L12(/!!(V"__[^_O?2(=`E@("`@'3IB<+!ZA"I@(````]$
MPDB-40)(#T3*B<(`PDR)XDB#V0-(*=F+,DB#P@2-AO_^_O[WUB'P)8"`@(!T
MZ8G&P>X0J8"````/1,9(C7("2`]$UHG&0`#&2(/:`TPIXHVL$00$``!(8^U(
MB>_H<>O__T%428G80;E]8$``:'IA0`!(B<=)B<:Y<6%``$C'PO____^^`0``
M`#'`Z./L__],B?>^P`$``.A6Z?__7T%8@_C_=1+H&>G__T2+"$&#^1$/A=<"
M``!(C90DD````$R)]K\!````Z$?L__^)PX7`#X2M````28M-`$B+/0*+``!-
MB?`QP+I@8D``O@$````Q[>A,[/__2(N,)'B!``!D2#,,)2@```!(B>@/A<X$
M``!(@<2(@0``6UU!7$%=05Y!7\,Q[68/'T0``$ACQ4B+7,0@2(7;=#N`.P!T
M-DB)WX/%`>@;]/__A<!TWTB)W^C_Z___2(G#2(7`#X5[_O__2&/%2(M<Q"!(
MA=MURV8/'T0``#';Z6'^__]F#Q^$``````"+A"2H````)0#P```]`$````^%
M//___T2+I"2L````Z!SI__]!.<0/A2;___^+A"2H````)?\!```]P`$```^%
M#____TB)[^@$ZO__2(UT)!R_06%``$B)Q3'`Z'#N__](A<`/A`\"``!(B<?H
M7^O__TF+?0!(B<;H(_;__TF)Q$B%P`^$[P$``$R)Y^B/Z/__@_@#?CI(8]"_
M?V%``+D%````28UT%/SSI@^7PH#:`(32=1R#^`0/A.P"``"#Z`1(F$&`?`3_
M+P^$VP(``&:0,<#HB?K__X7`=15,B><Q]N@;ZO__08G$A<`/A9$!``"^-&%`
M`+^\8$``,<!)Q\3_____Z"CO___HD^?__VB]84``38GP2(GO4$C'PO____]!
MN7U@0``QP+F884``O@$```#HN>K__UA:ZT8/'T0``.C[YO__@S@1=4GH4>?_
M_X/#`4B#[`A-B?!HO6%``+FF84``3(GB2(GO4T&Y?6!``+X!````4#'`Z'/J
M__](@\0@OL`!``!(B>_HXN;__X/X_W2M3(GWZ)7F__](B>Z_96!``#'`Z(;N
M__](B>_H3OK__^F]_?__9@\?A```````OT9A0``Q[>L/#Q^``````$ACQ4B+
M?,1`2(7_='U(C70D'#'`@\4!Z.3L__](A<!TWX`X`'3:2(G'Z-+I__](B<-(
MA<!TRNF>^___28M-`$B+/4J(``!-B?`QP+H@8D``O@$````Q[>B4Z?__Z4/]
M__\/'X``````2(G'2(E$)`CHN_G__TB+1"0(2(G'Z'[I__](B<7I&OW__[\-
M````NTMA0`#HY^?__TF)Q.E2^___#Q^``````$V+90#I"/[__[H"````2,?&
M[O___XG'Z!SI__^Z!@```$B-M"1P`0``1(GGZ$?G__^`O"1P`0```'4.@+PD
M<0$``$,/A"@!```QTC'V1(GGZ./H__\QP.C\&P``2(G#ZQD/'X``````B<)(
MC;0D<`$``$B)W^@^'```N@"```!(C;0D<`$``$2)Y^CIYO__A<!_U42)YTR-
MO"0@`0``2<?$_____^A^YO__2(G>2(V\)"`!``!(C9PD0`$``.BV'0``3(UK
M*&:010^V!TB)W[EL84``3(GBO@$````QP$B#PP))@\<!Z(WH__]).=UUV,:$
M)&@!````:+UA0`!(C80D2`$``%"YB6%``+X!````38GP0;E]8$``2,?"____
M_TB)[S'`Z$[H__]97NGJ_?__38MM"$V%[0^$&OW__TR)[^ABY?__2(/X`P^&
M"/W__TF-=`7\OX1A0`"Y!0```/.F#Y?`'`"$P$T/1.7IY_S__X"\)'(!``!!
M#X7*_O__@+PD<P$``$,/A;S^__^`O"1T`0``2`^%KO[__X"\)'4!``!%#X6@
M_O__N@(```!(Q\;&____1(GGZ'OG__](C;0D<`$``+HI````1(GGZ*;E__]H
MO6%``$B-A"1X`0``Z2'____HS^3__V9F+@\?A```````#Q]``$%6055!5%53
M2(/L$(L]GH4``&1(BP0E*````$B)1"0(,<#HJ>7__XL]@X4``$B)P^B;Y?__
M2(UT)`2_H&!```^VD[@```"(D+D````QP.@-ZO__2(7`=`F`.#$/A-\"```Q
MP.C(]/__BSU"A0``Z%WE__^Y"P```+H!````OK=A0`!(B<?H%N7__XLM((4`
M`$B%P`^$Q@```$B+0!"#/7R5```!3(MH*`^.L0```#';ZS%F#Q]$``!)BW80
M2(L-594``$ECU$B+/-'HP>3__XL52Y4``(7`=7N#PP(YTT2)XWUQB>]$C6,!
MZ.+D__\QR4ACTTR)[DB)Q^C"Y?__2(7`=$5,BS"++:2$``!!BT8,)0`$(``]
M``0``'2<B>_HK>3__TR)]KD"````,=)(B<?HV^/__XLM=80``$B)QNEY____
M#Q]$``"+%=*4``"++5R$``"-0O\YV`^$<0$``(GOZ&KD__^Y`P```+H!````
MOKQA0`!(B<?H(^3__TB)PTB%P'0S2(M`$(L](80``$B+*.@YY/__NKYA0`!(
MB<=(B>[H6>/__TB+0Q!(BQCV0PY`#X7$`0``BSWR@P``Z`WD__^Y`P```+H!
M````OL-A0`!(B<?HQN/__TB)PTB%P'0]2(UT)`2_;F!``#'`Z&WH__](B<5(
MA<`/A%$!``!(BT,0BSVG@P``2(L8Z+_C__](B>I(B=Y(B<?HX>+__XL]BX,`
M`.BFX___N@$```"^Q6%``$B)Q^BTX___BSUN@P``2(G#Z(;C__](B=ZZVF%`
M`$B)Q^BFXO__BSU0@P``Z&OC__](C70D!+]E8$``QH"Y`````#'`Z./G__](
MB<-(B06ADP``2(7`#X2`````OL`!``!(B=_H8^'__XU0`8/Z`78)@_@1#X7N
M````2(M$)`AD2#,$)2@````/A=4```!(@\006UU!7$%=05[#D(/Z`0^.AO[_
M_[L!````9I")[X/#`>CFXO__3(GN2(G'Z"OA__\Y'263``"++:^"``!_W>E7
M_O__#Q^$``````!(BST!DP``Z%3U__](B<-(B04"DP``2(7`#X5A____O[AB
M0``QP.C%XO__#Q]$``"`>`$`#X0>_?__Z1+]__^02(L%P9(``(L]4X(``$B+
M*$B+0Q!(BQCH9.+__TB)[DB)W^B)[/__Z:/^__^+/2Z"``#H2>+__TB)WDB)
MQ^BNXO__Z2'^___H).'__XG!2(L%<Y(``$B)VK_@8D``2(LP,<#H2>+__V8/
M'X0``````%5(B?U32(/L".B2\/__#[802(G#A-)T&@\?A```````2(/``8#Z
M+P^V$$@/1-B$TG7N,<#H]_+__TB%[70BA<!T'H!]``!T&+]Z84``N00```!(
MB=[SI@^7P!P`A,!T!TB#Q`A;7<-(@\0(2(GO6UWIV^G__V8N#Q^$``````"0
M05=,C4\X059!54%455-(@>R8`@``9$B+!"4H````2(F$)(@"```QP$B)XDR-
MDH````!)B=`/'P!!BP%)BS%)@\`028/!"`_(B<!(B?%)B4#P2(GP2,'I($C!
MZ"A(P>XX)0#_``!("?!(B<Y(P>$(2,'F&('A``#_`(GV2`GP2`G(28E`^$TY
MPG6N2(VR``(```\?@`````!(BT)H2#-"0$B#P@A(,T((2#-"^$B-#`!(P>@?
M2`G(@^#_2(E">$@Y\G753(L72(M?$$B+=R!(BV\83(G03(G23(M/"$C!ZAM(
MP>`%2`G0`P0DC90PF7F"6DB)V$B+="0(2#'H3"'(2(VT-9EY@EI(,>A$C2P"
M3(G*3(G(2,'H`DC!XAY-B>A("<)(B=A)P>@;B=%(,<A,(=!(,=A(`?!,B>Y(
MP>8%3`G&1(TD!DR)UDR)T$C!YAY(P>@"38GC2`GP2(MT)!!)P>L;2#'"08G`
M3"'J2(VT,YEY@EI(,<I(`?),B>9(P>8%3`G>1(T<%DR)[DG![0)(BU0D&$C!
MYAY,">Y(C901F7F"6DR)V4@Q\$&)]DPAX$PQP$C!Z1M(`=!,B=I(P>(%2`G*
M3(GA2<'L`DC!X1Y$C2P"2(GP2(M4)"!,">%,B>Y(,<A)C900F7F"6DC![AM!
MB<Q,(=A,,?!(`=!,B>I(P>(%2`GR1(T$`DR)VDG!ZP)(BT0D*$C!XAY,B<9,
M"=I)C80&F7F"6DC![AM(,=%!B=-,(>E,,>%(`<%,B<!(P>`%2`GP1(TT"$R)
MZ$G![0)(BTPD,$C!X!Y,B?9,">A)C8P,F7F"6D@QPD&)Q4PAPDPQVD@!RDR)
M\4C!X05(P>X;2`GQ3(G&2<'H`DC!YAY$C2012(M4)#A,"<9,B>%(,?!)C903
MF7F"6DC!Z1M!B?!,(?!,,>A(`=!,B>)(P>(%2`G*3(GQ2<'N`DC!X1Y$C1P"
M2(GP2(M4)$!,"?%,B=Y(,<A)C905F7F"6DC![AM!B<Y,(>!,,<!(`=!,B=I(
MP>(%2`GR1(TL`DR)XDG![`)(BT0D2$C!XAY,B>Y,">))C80`F7F"6DC![AM(
M,=%!B=1,(=E,,?%(`<%,B>A(P>`%2`GP1(T$"$R)V$G!ZP)(BTPD4$C!X!Y,
MB<9,"=A)C8P.F7F"6DC![AM(,<)!B<-,(>I,,>)(`<I,B<%(P>$%2`GQ3(GN
M2<'M`DC!YAY$C3012(M4)%A,">Y,B?%(,?!)C904F7F"6DC!Z1M!B?5,(<!,
M,=A(`=!,B?)(P>(%2`G*3(G!2<'H`DC!X1Y$C20"2(GP2(M4)&!,"<%,B>9(
M,<A)C903F7F"6DC![AM!B<A,(?!,,>A(`=!,B>)(P>(%2`GR1(T<`DR)\DB+
M1"1H2,'B'DG![@),B=Y,"?))C80%F7F"6DC![AM(,=%!B=9,(>%,,<%(`<%,
MB=A(P>`%2`GP1(TL"$R)X$G![`)(BTPD<$C!X!Y,B>Y,">!)C8P(F7F"6DC!
M[AM(,<)!B<1,(=I,,?)(`<I,B>E(P>$%2`GQ3(G>2<'K`DC!YAY$C0012(M4
M)'A,"=Y,B<%(,?!)C906F7F"6DC!Z1M!B?-,(>A,,>!(`=!,B<)(P>(%2`G*
M3(GI2<'M`DC!X1Y$C30"2(GP2(N4)(````!,">E,B?9(,<A)C904F7F"6DC!
M[AM!B<U,(<!,,=A(`=!,B?)(P>(%2`GR1(TD`DR)PDG!Z`)(BX0DB````$C!
MXAY,B>9,"<))C80#F7F"6DC![AM(,=%!B=!,(?%,,>E(`<%,B>!(P>`%2`GP
M2(NT))````!$C1P(3(GP2<'N`DC!X!Y)C;0UF7F"6DV)W4P)\$G![1M(,<*)
MP4PAXDPQPD@!\DR)WDC!Y@5,">Z)]D@!\DR)YDG![`)(P>8>08G53`GF3(ND
M))@```!(,?!,(=A/C80@F7F"6DV)[$@QR$G![!M,`<!-B>A)P>`%30G@18G`
M3`'`38G82<'K`DG!X!Y!B<1-"=A)B?.)]D@#M"2H````33'#1#':3(N<)*``
M``!*C8P9H>O9;DV)XT@!T4R)XDG!ZQM(P>(%3`G:B=)(`=%,B>I)P>T"2,'B
M'D&)RTP)ZDV)Q46)P$P#A"2P````23'51#'H38G=2(VT!J'KV6Y,B=A)P>T;
M2,'@!4P)Z(G`2`'P3(GF2<'L`DC!YAY!B<5,">9)B=2)TDDQ]$0QX4V)[$@#
ME"2X````38V$"*'KV6Y,B>E)P>P;2,'A!4P)X8G)20'(3(G92<'K`DC!X1Y%
MB<1,"=E)B?.)]D@#M"3`````23'+1#'838GC2(V4`J'KV6Y,B>!)P>L;2,'@
M!4P)V(G`2`'"3(GH2<'M`DC!X!Y!B=-,">A)B<V)R4@#C"3(````23'%13'H
M38G=3HV$!J'KV6Y,B=Y)P>T;2,'F!4P)[HGV3`'&38G@2<'L`DG!X!Y!B?5-
M">!)B<2)P$TQQ$0QXDV)[$B-C!&AZ]EN3(GJ2,'B!4G![!M(`X0DT````$P)
MXHG22`'13(G:2<'K`DC!XAY!B<Q,"=I-B<-%B<!,`X0DV````$DQTT0QWDV)
MXTB-M#"AZ]EN3(G@2<'K&TC!X`5,"=B)P$@!\$R)[DG![0)(P>8>08G#3`GN
M28G5B=)(`Y0DX````$DQ]40QZ4V)W4V-A`BAZ]EN3(G92<'M&TC!X05,">F)
MR4D!R$R)X4G![`)(P>$>18G%3`GA28GTB?9),<Q$,>!-B>Q(C90"H>O9;DR)
MZ$G![!M(P>`%3`G@B<!(`<),B=A)P>L"2`.T).@```!(P>`>08G43`G828G+
MB<E(`XPD\````$DQPT4QV$V)XTZ-A`:AZ]EN3(GF2<'K&TC!Y@5,"=Z)]DP!
MQDV)Z$G![0))P>`>08GS30GH28G%B<!(`X0D^````$TQQ40QZDV)W4B-C!&A
MZ]EN3(G:2<'M&TC!X@5,">J)TD@!T4R)XDG![`)(P>(>08G-3`GB38G$18G`
M23'41#'F38GL2(VT,*'KV6Y,B>A)P>P;2,'@!4P)X(G`2`'P3(G>2,'F'DG!
MZP)!B<1,`X0D``$``$P)WDF)TXG22`.4)`@!``!),?-$,=E-B>--C80(H>O9
M;DR)X4G!ZQM(P>$%3`G9B<E)`<A,B>E)P>T"2,'A'D6)PTP)Z4F)]8GV2`.T
M)!`!``!),<U$,>A-B=U(C90"H>O9;DR)V$G![1M(P>`%3`GHB<!(`<),B>!)
MP>P"2,'@'D&)U4P)X$F)S(G)23'$13'@38GL3HV$!J'KV6Y,B>Y)P>P;2,'F
M!4P)YHGV3`'&38G82<'K`DG!X!Y!B?1-"=A)B<-(`XPD&`$``(G`33'#2`.$
M)"`!``!$,=I-B>-(C8P1H>O9;DR)XDG!ZQM(P>(%3`G:B=)(`=%,B>I)P>T"
M2,'B'D&)RTP)ZDV)Q46)P$P#A"0H`0``23'51#'N38G=2(VT,*'KV6Y,B=A)
MP>T;2,'@!4P)Z(G`2`'P3(GF2<'L`DC!YAY!B<5,">9)B=2)TD@#E"0P`0``
M23'T1#'A38GL38V$"*'KV6Y,B>E)P>P;2,'A!4P)X8G)20'(3(G92<'K`DC!
MX1Y%B<1,"=E)B?.)]DDQRT0QV$V)XT@#M"0X`0``2(V4`J'KV6Y,B>!)P>L;
M2,'@!4P)V$2-'!!,B>A)P>T"2,'@'DP)Z$F)S8G)23'%B<)%,>A-B=U.C80&
MH>O9;DR)WDG![1M(P>8%3`GN3(NL)$`!``!&C30&38G@2<'L`DG!X!Y-">!,
M"<!$B<9)B<1(B=!((?!-(=Q)"<2XW+P;CTD!Q4P!Z4V)]4D!S$R)\4G![1M(
MP>$%3`GI28GU00',3(G92<'K`DC!X1Y,"=E!B<M)"<A-(?!-(=U-">A,BZPD
M2`$``$D!Q4P!ZDV)Y4D!T$R)XDG![1M(P>(%3`GJ1HTL`DR)\DG![@)(P>(>
M3`GR38G>08G02`G132'&3"'A3`GQ3(NT)%`!``!)`<9,`?9-B>Y(`?%,B>Y)
MP>X;2,'F!4P)]D2--`Y,B>9)P>P"2,'F'DP)YDV)Q(GQ2`GR22',3"'J3`GB
M3(ND)%@!``!)`<1-`>--B?1,`=I-B?-)P>,%2<'L&TT)XT6-)!--B>M)P>T"
M2<'C'DT)ZTF)S42)VDP)WDDAU4PA]DP)[DR+K"1@`0``20'%30'H38GE3`'&
M38G@2<'M&TG!X`5-">A%C2PP38GP2<'N`DG!X!Y-"?!)B=9$B<9-"<-)(?9-
M(>--"?-,B[0D:`$``$D!QDP!\4V)[DD!RTR)Z4G![AM(P>$%3`GQ1HTT&4R)
MX4G![`)(P>$>3`GA28GT08G+20G(32'H32'<30G@3(ND)'`!``!)`<1,`>)-
MB?1)`=!,B?))P>P;2,'B!4P)XD:-)`),B>I)P>T"2,'B'DP)ZDV)W4&)T$@)
MT4TAQ4PA\4P)Z4R+K"1X`0``20'%3`'N38GE2`'Q3(GF2<'M&TC!Y@5,">Y$
MC2P.3(GV2<'N`DC!YAY,"?9-B<:)\4@)\DDASDPAXDP)\DR+M"2``0``20'&
M30'S38GN3`':38GK2<'C!4G![AM-"?-%C30338GC2<'L`DG!XQY-">-)B<Q$
MB=I,"=Y)(=1,(>Y,">9,BZ0DB`$``$D!Q$T!X$V)]$P!QDV)\$G![!M)P>`%
M30G@18TD,$V)Z$G![0))P>`>30GH28G51(G&30G#22'U32'S30GK3(NL))`!
M``!)`<5,`>E-B>5)`<M,B>%)P>T;2,'A!4P)Z4:-+!E,B?%)P>X"2,'A'DP)
M\4F)]DD)R$&)RTTAWDTAX$T)\$R+M"28`0``20'&3`'R38GN20'03(GJ2<'N
M&TC!X@5,"?)&C30"3(GB2<'L`DC!XAY,">)-B=Q!B=!("=%-(<1,(>E,">%,
MBZ0DH`$``$D!Q$P!YDV)]$@!\4R)]DG![!M(P>8%3`GF1(TD#DR)[DG![0)(
MP>8>3`GN38G%B?%("?))(<U,(?),">I,BZPDJ`$``$D!Q4T!ZTV)Y4P!VDV)
MXTG![1M)P>,%30GK18TL$TV)\TG![@))P>,>30GS28G.1(G:3`G>22'63"'F
M3`GV3(NT)+`!``!)`<9-`?!-B>Y,`<9-B>A)P>X;2<'@!4T)\$6--#!-B>!)
MP>P"2<'@'DT)X$F)U$2)QDT)PTDA]$TAZTT)XTR+I"2X`0``20'$3`'A38GT
M20'+3(GQ2<'L&TC!X05,">%&C2093(GI2<'M`DC!X1Y,">E)B?5!B<M)"<A-
M(?!-(=U-">A,BZPDP`$``$D!Q4P!ZDV)Y4D!T$R)XDG![1M(P>(%3`GJ1HTL
M`DR)\DG![@)-B=A(P>(>3`GR08G62`G132'P3"'A3`G!3(N$),@!``!)`<!,
M`<9-B>A(`?%,B>Y)P>@;2,'F!4P)QD2-!`Y,B>9)P>P"3(GQ2,'F'DP)YD&)
M]$@)\DPAX4PAZD@)RDB+C"30`0``2`'!20'+3(G!2`.$)-@!``!,`=I-B<-(
MP>$%3`'P2<'K&TP)V8G)2`'*3(GI2<'M`DC!X1Y!B=-,">E-B>5!B<]("<Y-
M(?U,(<9,">Y-B=U(`?!,B=Y)P>T;2,'F!4P)[HGV2`'P3(G&2<'H`DC!YAY!
MB<5)"?"^UL%BRDPQP3'*2(N,).`!``!(`?%)`<Q,B>E,`>)-B>Q(P>$%2<'L
M&TP)X8G)2`'*3(G92,'A'DG!ZP)!B=1)"<M,B<%-B>9%B<!,,=E)P>X;,<A(
MBXPDZ`$``$@!\4D!STJ-##A,B>!(P>`%3`GPB<!,C30!3(GH2<'M`DR)V4C!
MX!Y%B?=%B=M)"<5(BX0D\`$``$PQZ4@!\#'*3(GY3`'`2,'I&T@!PDR)^$C!
MX`5("<A(BXPD^`$``(G`2`'"3(G@2`'Q2<'L`DC!X!Y,`=E-B>M!B=!,">!-
MB<1%B>U),<-)P>P;13'>3HT<,4R)P4C!X05,">&)R4D!RTR)^4G![P)(P>$>
M18G<20G/2(N,)``"``!(`?%,`>E)B<6)P$TQ_40QZDR-+!%,B>),B>%(P>D;
M2,'B!4@)RDR)P4G!Z`*)TDC!X1Y)`=5(BY0D"`(``$P)P4V)^$DQR$6)[D6)
M_T@!\D4QPT@!T$R)\DZ-!!A,B?!(P>H;2,'@!4@)T$B)RHG)B<!)`<!,B>!)
MP>P"2,'@'D6)PTD)Q$B+A"00`@``3#'B2`'P03'53(G:3`'X20'%3(G82,'@
M!4C!ZAM("=!,B?))P>X"B<!(P>(>20'%2(N$)!@"``!,"?)%B>](`?!(`<A,
MB>%%B>1(,=%!,<A,B?E)`<!,B?A(P>D;2,'@!4@)R(G`20'`3(G82<'K`DC!
MX!Y%B<9)"<-(BX0D(`(``$R)\4C!Z1M(`?!,`>!)B=2)TDTQW$4QY4Z-)"A,
MB?!(P>`%2`G(2(N,)"@"``")P$D!Q$R)^$@!\4G![P)(P>`>2`'*3(G918GE
M3`GX18G;2#'!03'(3(GI20'03(GJ2,'I&TC!X@5("<J)TDD!T$R)\DG![@)(
MP>(>18G'20G62(N4)#`"``!,B?E(P>D;2`'R3`':28G#B<!-,?-%,=Q.C1PB
M3(GZ2,'B!4@)RDR)Z4G![0*)TDC!X1Y)`=-(BY0D.`(``$P)Z46)W$@!\D@!
MT$R)\D6)]D@QRD$QT$R)XDD!P$R)X$C!ZAM(P>`%2`G02(G*B<F)P$D!P$R)
M^$G![P)(P>`>18G%20G'2(N$)$`"``!(`?!,,?I,`?!!,=-,B>I)`<-,B>A(
MP>H;2,'@!4@)T$R)XDG![`*)P$C!XAY)`<-(BX0D2`(``$P)XD6)WDF)U$@!
M\$@!R$R)^46)_T@QT8G203'(2HT,`$R)\$V)\$G!Z!M(P>`%3`G`B<!(`<%,
MB>A)P>T"2,'@'D&)R$D)Q4B+A"10`@``33'L2`'P13'C38G$3`'X2<'L&TD!
MPTR)P$C!X`5,">")P$D!PTR)\$C!X!Y)P>X"18G<3`GP3(NT)%@"``!)`?9)
M`=9,B>I%B>U(,<(QT4F-%`Y,B>%-B>9)P>X;2,'A!4P)\8G)2`'*3(G!2<'H
M`DC!X1Y!B=9)"<A(BXPD8`(``$@!\4P!Z4F)Q8G`33'%13'K38GU20'+3(GQ
M2<'M&TC!X05,">F)R4D!RTR)X4G![`)(P>$>18G=20G,2(N,)&@"``!(`?%(
M`<A,B<%%B<!,,>$QRDB-#!!,B>A,B>I(P>H;2,'@!4@)T$R)\DG![@)(P>(>
MB<!)"=9(BY0D<`(``$@!P8G(2`'R3`'"38G@33'P13'#28G`3`':28G#2<'@
M!4G!ZQM-"=A)B<-(P>@"2<'C'D$!T$R)ZDG![0))"<-(BX0D>`(``$C!XAY)
M"=5$B>)!`=M(`?!$`>U,B5\02`'"3(GP2(EO&$PQZ#'!2(T$"DR)PDR)P44!
MR$C!X@5(P>D;3(E'"$@)R@'000'"1`-W($R)%TR)=R!(BX0DB`(``&1(,P0E
M*````'422('$F`(``%M=05Q!74%>05_#Z&K*__]F+@\?A```````2(/L"+^`
M````Z'++__^ZB:O-[[G^W+J8OO#ATL-(QP`!(T5G2(E0"$B)2!!(QT`8=E0R
M$$B)<"!(QT`H`````$C'0#``````QT!X`````$B#Q`C#9F8N#Q^$``````"0
M05=(8\)!5DF)QD%5051)B?Q528UL)#A32(GS2(/L"$B+=RA(BU<PC0S&2#GQ
M2(E/*$B#T@!(P>@=2`'02(E',$AC?WB%_W160;U`````2(G>02G]13GN10].
M[D@![TUC_4R)^NB'RO__08M$)'A$`>A!B40D>(/X0'052(/$"%M=05Q!74%>
M05_#9@\?1```3(GG12GN3`'[Z.+H__]!@_X_#X[P````08/N0$6)]T'![P9%
MB?U)@\4!2<'E!DD!W0\?@`````#S#V\#3(GG2(/#0`\110#S#V]+T`\131#S
M#V]3X`\152#S#V];\`\173#HB>C__TPYZW7,0<'G!D4I_DECQDB#^`AR9$F+
M50!)B50D.$F+5`7X2(E4!?A(C54(2(/B^$@IU4DI[4@!Q4B#Y?A(@_T(<AA(
M@^7X,<!)BTP%`$B)#`)(@\`(2#GH<NY%B70D>$B#Q`A;74%<05U!7D%?PV8N
M#Q^$``````"H!'4L2(7`=-E!#[95`$&(5"0XJ`)TRT$/MU0%_F:)5`7^Z[X/
M'T``28G=Z6/___]!BU4`08E4)#A!BU0%_(E4!?SKGF9F+@\?A```````D$%6
M3(UV.$%505152(G]4TB+1BA(B?-$BV8H1(MN,$C!Z`.#X#]!#\Q!#\V-2`%(
MF,9$!CB`2&/!3`'P@_DX#XXD`0``ND`````IRHG1=`\QTHG6@\(!Q@0P`#G*
M<O-(B=_H6N?__V8/[\`/$4,X2<=&,`````!!#Q%&$$$/$48@1(EK<$B)WT2)
M8W3H,.?__TB+`TB)WTC!Z!B(10!(BP-(P>@0B$4!2(L#2,'H"(A%`DB+`XA%
M`TB+0PA(P>@8B$4$2(M#"$C!Z!"(105(BT,(2,'H"(A%!DB+0PB(10=(BT,0
M2,'H&(A%"$B+0Q!(P>@0B$4)2(M#$$C!Z`B(10I(BT,0B$4+2(M#&$C!Z!B(
M10Q(BT,82,'H$(A%#4B+0QA(P>@(B$4.2(M#&(A%#TB+0R!(P>@8B$402(M#
M($C!Z!"(11%(BT,@2,'H"(A%$DB+0R!;B$4374%<05U!7NG<Q?__#Q]``+HX
M````,?\IRH/Z"',J]L($=6V%T@^$_?[__\8``/;"`@^$\?[__S')9HE,$/[I
MY?[__P\?1```B=%(QP``````2,=$"/@`````2(U("$B#X?A(*<@!PH/B^(/Z
M"`^"M?[__X/B^#'`B<:#P`A(B3PQ.=!R\^F>_O__9@\?1```QP``````QT00
M_`````#IA?[__P\?1```2(L-$04``.G$QO__#Q]``$%728G7059)B?9!54&)
M_4%43(TEV&(``%5(C2W88@``4TPIY4B#[`CHT\3__TC!_0-T&S';#Q\`3(GZ
M3(GV1(GO0?\4W$B#PP%(.=UUZDB#Q`A;74%<05U!7D%?PP\?`,,```!(@^P(
M2(/$",,`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`````````````````"XN`"5S+R5S`"]P<F]C+W-E;&8O97AE
M`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ
M0D]/5``O<')O8R\E:2\E<P!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%
M4DPU3$E"`%!%4DQ,24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%
M1`!005)?4U!!5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!0
M05)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`
M4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q
M`$Q$7TQ)0E)!4EE?4$%42`!54T52`%-94U1%30`O=&UP`%1%35!$25(`5$U0
M`%5315).04U%`"4P,G@`)7,E<R5S)7,`<&%R+0!P87)L`"YP87(`)7,E<V-A
M8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`$%21U8`
M&`!P97)L`#``4$%2.CI086-K97(Z.E9%4E-)3TX`,2XP-#@`+64`+2T```!?
M7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(```````````<&5R;'AS
M:2YC`````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R
M>2`E<R!F86EL960@*&5R<FYO/25I*0H````````E<SH@<')I=F%T92!S=6)D
M:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R
M971R>2!Y;W5R(&]P97)A=&EO;BD*````````56YA8FQE('1O(&-R96%T92!C
M86-H92!D:7)E8W1O<GD``````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E
M(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````
M`````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")]
M)PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G
M92!?7W!A<E]P;#L*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL
M92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE
M.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z
M.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D
M<&%R7W1E;7`I.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E
M;7`B?2D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R
M;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`[
M"FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D
M=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L
M"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&
M1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@(B,A
M+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@
M)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R
M96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@
M)'1M<"T^9FEL96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I;&5N
M86UE.PIM>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@
M,CXF,2`F)SL*8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q*%-P
M87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@
M*0HN("1T;7`M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z
M.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4
M.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM0
M05)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/
M(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>
M3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*
M7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@
M)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY
M("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L("1324=[7U]705).
M7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S
M=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1P<F]G
M;F%M93L*;7D@)&]F9G-E="`](#4Q,CL*;7D@)&ED>"`]("TQ.PIW:&EL92`H
M,2D*>PHD;V9F<V5T(#T@)'-I>F4@:68@)&]F9G-E="`^("1S:7IE.PIS965K
M(%]&2"P@+21O9F9S970L(#(@;W(@9&EE('%Q6W-E96L@9F%I;&5D(&]N("(D
M<')O9VYA;64B.B`D(5T["FUY("1N<F5A9"`](')E860@7T9(+"`D8G5F+"`D
M;V9F<V5T.PID:64@<7%;<F5A9"!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A
M72!U;FQE<W,@)&YR96%D(#T]("1O9F9S970["B1I9'@@/2!R:6YD97@H)&)U
M9BP@(EQN4$%2+G!M7&XB*3L*;&%S="!I9B`D:61X(#X](#`@?'P@)&]F9G-E
M="`]/2`D<VEZ92!\?"`D;V9F<V5T(#X@,C4V("H@,3`R-#L*)&]F9G-E="`J
M/2`R.PI]"FQA<W0@=6YL97-S("1I9'@@/CT@,#L*)&]F9G-E="`M/2`D:61X
M("T@-#L*<V5E:R!?1D@L("TD;V9F<V5T+"`R.PIR96%D(%]&2"P@)&)U9BP@
M-#L*<V5E:R!?1D@L("TD;V9F<V5T("T@=6YP86-K*").(BP@)&)U9BDL(#([
M"G)E860@7T9(+"`D8G5F+"`T.PHD9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@
M-#L*;7D@)7)E<75I<F5?;&ES=#L*=VAI;&4@*"1B=68@97$@(D9)3$4B*2![
M"G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").
M(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7$H56YP86-K
M:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@)&-R8R`]("@@)&9U;&QN
M86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@
M*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<
M+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N
M<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A
M?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W1E
M;7!F:6QE*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H
M("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&)A<V5N
M86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I;&5N86UE
M7&XB*3L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*)%!!
M4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D
M8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["GT*<F5A
M9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E
M;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A
M)&UO9'5L93L*;7D@)&EN9F\@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D
M=6QE?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF
M;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F
M24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F
M:6QE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIP<FEN="`D9F@@)&EN9F\M
M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R;B`D9F@["GT*96QS92![
M"FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&EN9F\M/GMC<F-]+G!M(BP@
M)&EN9F\M/GMB=69]*3L*;W!E;B!M>2`D9F@L("<\)RP@)&9I;&5N86UE(&]R
M(&1I92`B8V%N)W0@<F5A9"`D9FEL96YA;64Z("0A(CL*8FEN;6]D92@D9F@I
M.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A
M;FYO="!F:6YD("1M;V1U;&4A7&XB.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO
M861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y
M.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I
M;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE
M<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I
M('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I
M;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M
M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER
M95]L:7-T>R1F:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<
M,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0IM>2!`
M<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N
M86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@
M*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@
M=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D
M05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D
M:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R
M"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A
M<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS
M:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6
M.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O
M7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),
M8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S
M:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L
M(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R
M7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]
M"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I
M9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@
M97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO
M<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N
M(&QO9SH@)"$B.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@
M/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD
M>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*
M<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL
M97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6
M.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF
M("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E
M.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T
M*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PI!<F-H:79E
M.CI::7`Z.G-E=$-H=6YK4VEZ92@Q,C@J,3`R-"D["F]P96X@;7D@)&9H+"`G
M/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*8FEN
M;6]D92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C
M:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F
M:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE(")2
M96%D("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D;R!["FEF("@D
M>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I
M*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ
M+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FQO
M8V%L("0O(#T@7#0["FEF("AD969I;F5D("1P87(I('L*;W!E;B!005(L("<\
M)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D92A005(I.PID:64@
M(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<
M,#`S7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&
M:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL
M93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@
M;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN960@)&1A=&%?
M<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L(#`L(#`["FUY
M("1L;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A)$5.5GM005)?5D520D%4
M24U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E
M(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*?0IF;W)E86-H(&UY("1K97D@
M*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K97E](&]R(&YE
M>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D
M;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S
M970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D97(@/7X@
M<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H
M*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D
M97(I.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ
M2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I
M;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"
M4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE
M("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIM>2`E9FEL97,["B1F
M:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S
M+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[
M;&EB7V5X='T["FUY("5W<FET=&5N.PIF;W)E86-H("AS;W)T(&ME>7,@)69I
M;&5S*2!["FUY("@D;F%M92P@)&9I;&4I.PIF;W)E86-H(&UY("1D:7(@*$!I
M;F,I('L*:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI
M('L*)&9I;&4@/2`D7SL*;&%S=#L*?0IE;'-I9B`H+UXH7%$D9&ER7$5<+R@N
M*EM>0V-=*2E<6B]I*2!["B@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["FQA
M<W0["GT*96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2![
M"FEF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@
M>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*96QS:68@
M*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L
M("0Q*3L*;&%S=#L*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A
M;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I
M(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*;W5T<R@@:F]I;B`B
M(BP*<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z
M("1F:6QE+`IQ<2@B+BXN*0HI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL
M92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["F]P96X@
M1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A
M(CL*8FEN;6]D92A&24Q%*3L*)&-O;G1E;G0@/2`\1DE,13X["F-L;W-E($9)
M3$4["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E
M;G0L("1F:6QE*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]
M?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E
M;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"F]U
M=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B1F:"T^<')I;G0H(D9)3$4B
M*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*
M)&9H+3YP<FEN="AS<')I;G1F*`HB)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ
M8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64**2D["B1F:"T^<')I;G0H
M<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*)&9H+3YP<FEN="@D8V]N
M=&5N="D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z
M:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*
M:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI
M6SE=*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N*&UY
M("1F:"P@(CPB+"`D;W5T*3L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE
M*"1F:"D["F-L;W-E*"1F:"D["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG
M97-T.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A
M8VAE7VYA;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT
M*"1C86-H95]N86UE*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL
M("T@;&5N9W1H*"1L;V%D97(I*2D["B1F:"T^<')I;G0H(EQN4$%2+G!M7&XB
M*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA
M<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I
M.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I
M.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`[
M"GT*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H,C4V*C$P,C0I.PIM>2`D
M>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["FUY("1F:"`]($E/.CI&:6QE+3YN
M97<["B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z
M("1`(CL*)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE
M*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PIP
M=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O
M9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;W5T
M<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["FEF
M("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A
M="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB
M97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M
M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE
M;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG
M>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\*
M*%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T
M7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D
M97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D
M;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<2A3:VEP<&EN
M9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B
M)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ<2A%>'1R86-T:6YG("(D
M;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PHD;65M8F5R+3YE>'1R
M86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L("1D97-T
M7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2
M.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!
M4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO
M9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@
M72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@
M)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A
M=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64[
M"FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE
M.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0
M871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T
M:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO
M9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U
M:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S
M.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(
M96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD[
M"G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL
M93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R
M.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E
M($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R
M8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005([
M"G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I
M<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R
M.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E
M<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R
M97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E
M.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.
M86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E
M(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS
M=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]
M(&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@
M)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1?
M?2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL
M"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE
M9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA
M;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@
M:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA
M;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I
M9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L
M<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]
M('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T
M;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J
M(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.
M5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I
M*5LY72D@>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D
M9F@L("TQ."P@,CL*<WES<F5A9"`D9F@L(&UY("1B=68L(#8["FEF("@D8G5F
M(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIS>7-R96%D("1F
M:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#
M;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIR97%U:7)E
M($1I9V5S=#HZ4TA!.PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*
M;W!E;BAM>2`D9F@L("(\(BP@)'!R;V=N86UE*3L*8FEN;6]D92@D9F@I.PHD
M8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["B1S=&UP9&ER("X]("(D
M0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&-T>"T^:&5X9&EG97-T.PI]"F-L
M;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP
M9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]4
M14U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*
M?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM0
M05)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&YA
M;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D
M<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D
M=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;W!E;B!M>2`D9F@L("<^)RP@
M)'1E;7!N86UE(&]R(&1I92`B8V%N)W0@=W)I=&4@)'1E;7!N86UE.B`D(2([
M"F)I;FUO9&4@)&9H.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC;&]S92`D9F@[
M"F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N
M86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE
M*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*
M:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]0
M4D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G
M;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R
M;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S
M=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D
M96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD
M97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*:68@*&]P
M96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H
M.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N
M86UE("X]("1#;VYF:6=[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@
M)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%4
M2'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@
M97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM
M?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R
M;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M
M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF
M("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?
M9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!2
M3T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]
M*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA
M;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D
M.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS
M,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@
M/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I
M9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]
M"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%
M1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)
M04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%
M0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD
M7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD
M14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X
M:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@
M/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.
M5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I
M9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU
M92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D[
M"B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!
M3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF
M("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I
M;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<[
M"G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG
M>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S
M:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C
M:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ
M9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<2AP87(N
M<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U
M8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE("1P<F]G;F%M93L*
M9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%
M6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@
M/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]
M?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z
M.E]?15)23U(["C$["E]?14Y$7U\*``$;`SO\````'@```)B#__](`0``>(?_
M_X0%``!HB?__&`$``$B*__]P`0``&(O__[P!``"HB___X`$``/B-__\L`@``
M6(___V@"``#HC___C`(``,B0___(`@``^)#__^`"``!(D?__^`(```B2__\<
M`P``&)+__S`#```8E/__B`,``$B4__^<`P``&)7__\@#``#8EO__Y`,``%B7
M__\`!```>)?__Q@$``!8F/__6`0``.B?__\,!0``J*/__U`%```HI/__J`4`
M`$BZ___X!0``J+K__Q`&``!HO/__=`8``&B^__^X!@``>+[__]`&``#8OO__
M&`<````````4``````````%Z4@`!>!`!&PP'")`!!Q`4````'````$B(__\K
M```````````````4``````````%Z4@`!>!`!&PP'")`!```D````'````$B"
M___@`P````X01@X82@\+=PB``#\:.RHS)"(`````2````$0```#0B/__S```
M``!"#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&00XX@P=$#D`";`H..$0.,$$.
M*$(.($(.&$(.$$(."$D+`"````"0````5(G__X,`````00X0@P)'#B`"=`H.
M$$$."$$+`$@```"T````P(G__TL"````0@X0CP)"#AB.`T(.((T$0@XHC`5!
M#C"&!D0..(,'1PY@`Q<!"@XX00XP00XH0@X@0@X80@X00@X(2PLX``````$`
M`,2+__]<`0```$(.$(T"0@X8C`-!#B"&!$$.*(,%1P[0`7X*#BA!#B!!#AA"
M#A!"#@A'"P`@````/`$``.B,__^+`````$$.$(,"4@ZP`0)Q"@X000X(00LX
M````8`$``%2-___4`````$(.$(T"2@X8C`-!#B"&!$D.*(,%1P[`(`)^"@XH
M00X@00X80@X00@X(1PL4````G`$``/B-__\J`````$0.$&$."``4````M`$`
M`!".__]$`````$0.$'L."``@````S`$``$B.__^T`````$$.$(,"1PZP0`*E
M"@X000X(00L0````\`$``.2.__\%`````````%0````$`@``X([___\!````
M0@X0C@)"#AB-`T4.((P$00XHA@5)#C"#!D<.X"$"8@H.,$$.*$$.($(.&$(.
M$$(."$0+`HX.Z"%+#O`A=0[H(4$.X"$````0````7`(``(B0__\I````````
M`"@```!P`@``I)#__\,`````4PX0@P("2PK##@A*"WP."$3#4`X0@P)&PPX(
M&````)P"``!(D?__L@$```!$#E`#3@$*#@A&"Q@```"X`@``[)+__W(`````
M1`X@;PH."$4+```4````U`(``%"3__\=`````$0.$%@."``\````[`(``%B3
M___1`````$(.$(P"00X8A@-)#B"#!$0.,`)*"@X@00X800X00@X(0@MN#CA)
M#D!O#CA!#C``L````"P#``#XD___@0<```!"#A"/`D(.&(X#0@X@C01*#BB,
M!4$.,(8&00XX@P='#L"#`@/H`0[(@P).#M"#`FP.R(,"0@[`@P(">`H..$$.
M,$$.*$(.($(.&$(.$$(."$$+`W(!#LB#`D<.T(,"7P[(@P)!#L"#`ET.R(,"
M2`[0@P),#MB#`DP.X(,"2P[`@P(#]`$.R(,"20[0@P)E#LB#`D$.P(,"`JL*
M#LB#`DT+````0````.`#``#4FO__MP,```!"#A".`D(.&(T#0@X@C`1!#BB&
M!4$.,(,&1`Y``[H""@XP00XH00X@0@X80@X00@X(0@LP````)`0``%">__]U
M`````$$.$(8"1`X8@P-$#B`"6PH.&$$.$$$."$$+1`X81`X000X((````%@$
M``#L@?__[`$```!!#A"#`D0.0`.3`0H.$$$."$$+3````'P$``!XGO__%A8`
M``!"#A"/`D8.&(X#0@X@C01"#BB,!4$.,(8&00XX@P='#M`%`_$5"@XX00XP
M00XH0@X@0@X80@X00@X(00L````4````S`0``$BT__]4`````$0.$`)/#@A@
M````Y`0``)"T__^T`0```$(.$(\"10X8C@-%#B"-!$(.*(P%1`XPA@9&#CB#
M!T<.0`)@"@XX00XP00XH0@X@0@X80@X00@X(1PL"RPH..$$.,$$.*$(.($(.
M&$(.$$(."$L+0````$@%``#LM?__^P$```!"#A".`D8.&(T#0@X@C`1!#BB&
M!40.,(,&`T8!"@XH1`X@0@X80@X00@X(20L````````4````C`4``*BW__\,
M``````````````!$````I`4``*"W__]=`````$(.$(\"10X8C@-%#B"-!$4.
M*(P%2`XPA@9(#CB#!T<.0&H..$$.,$$.*$(.($(.&$(.$$(."``0````[`4`
M`+BW__\!````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#`)D```````)`F0````````0``````
M```!``````````$`````````A@$````````!`````````-4!````````#```
M````````($````````T`````````9%M````````9`````````/"]0```````
M&P`````````(`````````!H`````````^+U````````<``````````@`````
M````]?[_;P`````(`T````````4`````````*`Y````````&`````````.`$
M0```````"@````````"&!`````````L`````````&``````````5````````
M`````````````P``````````P$````````(`````````N`4````````4````
M``````<`````````%P````````"(%$````````<`````````^!-````````(
M`````````)``````````"0`````````8`````````/[__V\`````>!-`````
M``#___]O``````(`````````\/__;P````"N$D``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````OD`````````````````````````````V($```````$8@
M0```````5B!```````!F($```````'8@0```````AB!```````"6($``````
M`*8@0```````MB!```````#&($```````-8@0```````YB!```````#V($``
M``````8A0```````%B%````````F(4```````#8A0```````1B%```````!6
M(4```````&8A0```````=B%```````"&(4```````)8A0```````IB%`````
M``"V(4```````,8A0```````UB%```````#F(4```````/8A0```````!B)`
M```````6(D```````"8B0```````-B)```````!&(D```````%8B0```````
M9B)```````!V(D```````(8B0```````EB)```````"F(D```````+8B0```
M````QB)```````#6(D```````.8B0```````]B)````````&(T```````!8C
M0```````)B-````````V(T```````$8C0```````5B-```````!F(T``````
M`'8C0```````AB-```````"6(T```````*8C0```````MB-```````#&(T``
M`````-8C0```````YB-```````#V(T``````````````````_____P`````H
M8T```````$=#0SH@*$=.52D@."XR+C$@,C`Q.#$R,34@*$%,5"!3:7-Y<&AU
M<R`X+C(N,2UA;'0R*0!'0T,Z("A'3E4I(#@N,RXQ(#(P,3DP,S$Q("A!3%0@
M4VES>7!H=7,@."XS+C$M86QT,RD`+4D@+BXO:6YC;'5D90`M22`O=7-R+W-R
M8R]24$TO0E5)3$0O9VQI8F,M,BXR-RUA;'0X+V)U:6QD+7@X-E\V-"UL:6YU
M>"]C<W4`+4D@+W5S<B]S<F,O4E!-+T)524Q$+V=L:6)C+3(N,C<M86QT."]B
M=6EL9"UX.#9?-C0M;&EN=7@`+4D@+BXO<WES9&5P<R]U;FEX+W-Y<W8O;&EN
M=7@O>#@V7S8T+S8T`"U)("XN+W-Y<V1E<',O=6YI>"]S>7-V+VQI;G5X+W@X
M-E\V-``M22`N+B]S>7-D97!S+W5N:7@O<WES=B]L:6YU>"]X.#8`+4D@+BXO
M<WES9&5P<R]X.#8O;G!T;``M22`N+B]S>7-D97!S+W5N:7@O<WES=B]L:6YU
M>"]W;W)D<VEZ92TV-``M22`N+B]S>7-D97!S+W@X-E\V-"]N<'1L`"U)("XN
M+W-Y<V1E<',O=6YI>"]S>7-V+VQI;G5X+VEN8VQU9&4`+4D@+BXO<WES9&5P
M<R]U;FEX+W-Y<W8O;&EN=7@`+4D@+BXO<WES9&5P<R]N<'1L`"U)("XN+W-Y
M<V1E<',O<'1H<F5A9``M22`N+B]S>7-D97!S+V=N=0`M22`N+B]S>7-D97!S
M+W5N:7@O:6YE=``M22`N+B]S>7-D97!S+W5N:7@O<WES=@`M22`N+B]S>7-D
M97!S+W5N:7@O>#@V7S8T`"U)("XN+W-Y<V1E<',O=6YI>``M22`N+B]S>7-D
M97!S+W!O<VEX`"U)("XN+W-Y<V1E<',O>#@V7S8T+S8T`"U)("XN+W-Y<V1E
M<',O>#@V7S8T+V9P=2]M=6QT:6%R8V@`+4D@+BXO<WES9&5P<R]X.#9?-C0O
M9G!U`"U)("XN+W-Y<V1E<',O>#@V+V9P=2]I;F-L=61E`"U)("XN+W-Y<V1E
M<',O>#@V+V9P=0`M22`N+B]S>7-D97!S+W@X-E\V-"]M=6QT:6%R8V@`+4D@
M+BXO<WES9&5P<R]X.#9?-C0`+4D@+BXO<WES9&5P<R]X.#8`+4D@+BXO<WES
M9&5P<R]I965E-S4T+V9L;V%T,3(X`"U)("XN+W-Y<V1E<',O:65E93<U-"]L
M9&)L+3DV+VEN8VQU9&4`+4D@+BXO<WES9&5P<R]I965E-S4T+VQD8FPM.38`
M+4D@+BXO<WES9&5P<R]I965E-S4T+V1B;"TV-"]W;W)D<VEZ92TV-``M22`N
M+B]S>7-D97!S+VEE964W-30O9&)L+38T`"U)("XN+W-Y<V1E<',O:65E93<U
M-"]F;'0M,S(`+4D@+BXO<WES9&5P<R]W;W)D<VEZ92TV-``M22`N+B]S>7-D
M97!S+VEE964W-30`+4D@+BXO<WES9&5P<R]G96YE<FEC`"U)("XN`"U)("XN
M+VQI8FEO`"U)("X`+4U$("]U<W(O<W)C+U)032]"54E,1"]G;&EB8RTR+C(W
M+6%L=#@O8G5I;&0M>#@V7S8T+6QI;G5X+V-S=2]I;FET+F0`+4U&("]U<W(O
M<W)C+U)032]"54E,1"]G;&EB8RTR+C(W+6%L=#@O8G5I;&0M>#@V7S8T+6QI
M;G5X+V-S=2]I;FET+F\N9'0`+4U0`"U-5"`O=7-R+W-R8R]24$TO0E5)3$0O
M9VQI8F,M,BXR-RUA;'0X+V)U:6QD+7@X-E\V-"UL:6YU>"]C<W4O:6YI="YO
M`"U$(%-404-+7U!23U1%0U1/4E],159%3#TP`"U5(%]&3U)424997U-/55)#
M10`M1"!?3$E"0U]2145.5%)!3E0`+40@34]$54Q%7TY!344];&EB8P`M1"!4
M3U!?3D%-15-004-%/6=L:6)C`"UI;F-L=61E("]U<W(O<W)C+U)032]"54E,
M1"]G;&EB8RTR+C(W+6%L=#@O8G5I;&0M>#@V7S8T+6QI;G5X+VQI8F,M;6]D
M=6QE<RYH`"UI;F-L=61E("XN+VEN8VQU9&4O;&EB8RUS>6UB;VQS+F@`+6UT
M=6YE/6=E;F5R:6,`+6UA<F-H/7@X-BTV-``M875X8F%S92US=')I<"`O=7-R
M+W-R8R]24$TO0E5)3$0O9VQI8F,M,BXR-RUA;'0X+V)U:6QD+7@X-E\V-"UL
M:6YU>"]C<W4O:6YI="YO`"UG`"U/,@`M5V%L;``M5V5R<F]R`"U7=6YD968`
M+5=W<FET92US=')I;F=S`"U7<W1R:6-T+7!R;W1O='EP97,`+5=O;&0M<W1Y
M;&4M9&5F:6YI=&EO;@`M<W1D/6=N=3$Q`"UF9VYU.#DM:6YL:6YE`"UF;65R
M9V4M86QL+6-O;G-T86YT<P`M9G)E8V]R9"UG8V,M<W=I=&-H97,`+69R;W5N
M9&EN9RUM871H`"UF<W1A8VLM<')O=&5C=&]R+7-T<F]N9P`M9FYO+7-T86-K
M+7!R;W1E8W1O<@`M9G1L<RUM;V1E;#UI;FET:6%L+65X96,`+4U$("]U<W(O
M<W)C+U)032]"54E,1"]G;&EB8RTR+C(W+6%L=#@O8G5I;&0M>#@V7S8T+6QI
M;G5X+V-S=2]S=&%T:6,M<F5L;V,N9``M348@+W5S<B]S<F,O4E!-+T)524Q$
M+V=L:6)C+3(N,C<M86QT."]B=6EL9"UX.#9?-C0M;&EN=7@O8W-U+W-T871I
M8RUR96QO8RYO+F1T`"U-5"`O=7-R+W-R8R]24$TO0E5)3$0O9VQI8F,M,BXR
M-RUA;'0X+V)U:6QD+7@X-E\V-"UL:6YU>"]C<W4O<W1A=&EC+7)E;&]C+F\`
M<W1A=&EC+7)E;&]C+F,`+6%U>&)A<V4M<W1R:7`@+W5S<B]S<F,O4E!-+T)5
M24Q$+V=L:6)C+3(N,C<M86QT."]B=6EL9"UX.#9?-C0M;&EN=7@O8W-U+W-T
M871I8RUR96QO8RYO`"U)("]U<W(O;&]C86PO:6YC;'5D90`M22`O=7-R+VQI
M8C8T+W!E<FPU+T-/4D4`+40@7U)%14Y44D%.5``M1"!?1TY57U-/55)#10`M
M1"!?3$%21T5&24Q%7U-/55)#10`M1"!?1DE,15]/1D93151?0DE44STV-``M
M1"!,1$Q)0E!42$Y!344](DQ$7TQ)0E)!4EE?4$%42"(`+40@4$%23%]%6$4]
M(G!A<FPB`"U$(%!!4E]004-+15)?5D524TE/3CTB,2XP-#@B`&UA:6XN8P`M
M9G=R87!V`"UF;F\M<W1R:6-T+6%L:6%S:6YG`"U$($)95$5/4D1%4CTP>#$R
M,S0U-C<X`"U$(%4V-%194$4]=6YS:6=N960@;&]N9P!S:&$Q+F,`+4D@+W5S
M<B]S<F,O4E!-+T)524Q$+V=L:6)C+3(N,C<M86QT."]B=6EL9"UX.#9?-C0M
M;&EN=7@O;G!T;``M340@+W5S<B]S<F,O4E!-+T)524Q$+V=L:6)C+3(N,C<M
M86QT."]B=6EL9"UX.#9?-C0M;&EN=7@O;G!T;"]P=&AR96%D7V%T9F]R:RYD
M`"U-1B`O=7-R+W-R8R]24$TO0E5)3$0O9VQI8F,M,BXR-RUA;'0X+V)U:6QD
M+7@X-E\V-"UL:6YU>"]N<'1L+W!T:')E861?871F;W)K+F]3+F1T`"U-5"`O
M=7-R+W-R8R]24$TO0E5)3$0O9VQI8F,M,BXR-RUA;'0X+V)U:6QD+7@X-E\V
M-"UL:6YU>"]N<'1L+W!T:')E861?871F;W)K+F]3`"U$($U/1%5,15].04U%
M/6QI8G!T:')E860`+40@4$E#`"U$($Q)0D-?3D].4TA!4D5$/3$`<'1H<F5A
M9%]A=&9O<FLN8P`M875X8F%S92US=')I<"`O=7-R+W-R8R]24$TO0E5)3$0O
M9VQI8F,M,BXR-RUA;'0X+V)U:6QD+7@X-E\V-"UL:6YU>"]N<'1L+W!T:')E
M861?871F;W)K+F]3`"UF4$E#`"U-1"`O=7-R+W-R8R]24$TO0E5)3$0O9VQI
M8F,M,BXR-RUA;'0X+V)U:6QD+7@X-E\V-"UL:6YU>"]C<W4O96QF+6EN:70N
M9``M348@+W5S<B]S<F,O4E!-+T)524Q$+V=L:6)C+3(N,C<M86QT."]B=6EL
M9"UX.#9?-C0M;&EN=7@O8W-U+V5L9BUI;FET+F]3+F1T`"U-5"`O=7-R+W-R
M8R]24$TO0E5)3$0O9VQI8F,M,BXR-RUA;'0X+V)U:6QD+7@X-E\V-"UL:6YU
M>"]C<W4O96QF+6EN:70N;U,`96QF+6EN:70N8P`M875X8F%S92US=')I<"`O
M=7-R+W-R8R]24$TO0E5)3$0O9VQI8F,M,BXR-RUA;'0X+V)U:6QD+7@X-E\V
M-"UL:6YU>"]C<W4O96QF+6EN:70N;U,``"YS:'-T<G1A8@`N:6YT97)P`"YN
M;W1E+D%"22UT86<`+FYO=&4N9VYU+F)U:6QD+6ED`"YG;G4N:&%S:``N9'EN
M<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA
M+F1Y;@`N<F5L82YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?
M9G)A;65?:&1R`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N
M9'EN86UI8P`N9V]T`"YG;W0N<&QT`"YD871A`"YB<W,`+F-O;6UE;G0`+D=#
M0RYC;VUM86YD+FQI;F4`````````````````````````````````````````
M``````````````````````````````````````````````````L````!````
M`@````````"H`D```````*@"````````'`````````````````````$`````
M```````````````3````!P````(`````````Q`)```````#$`@```````"``
M```````````````````$````````````````````(0````<````"````````
M`.0"0```````Y`(````````D````````````````````!```````````````
M`````#0```#V__]O`@`````````(`T````````@#````````U`$````````%
M``````````@````````````````````^````"P````(`````````X`1`````
M``#@!````````$@)````````!@````$````(`````````!@`````````1@``
M``,````"`````````"@.0```````*`X```````"&!```````````````````
M`0```````````````````$X```#___]O`@````````"N$D```````*X2````
M````Q@`````````%``````````(``````````@````````!;````_O__;P(`
M````````>!-```````!X$P```````(``````````!@````(````(````````
M````````````:@````0````"`````````/@30```````^!,```````"0````
M``````4`````````"``````````8`````````'0````$````0@````````"(
M%$```````(@4````````N`4````````%````%@````@`````````&```````
M``!^`````0````8``````````"!`````````(````````!<`````````````
M```````$````````````````````>0````$````&`````````"`@0```````
M("````````#@`P``````````````````$``````````0`````````(0````!
M````!@``````````)$`````````D````````83<``````````````````!``
M``````````````````"*`````0````8`````````9%M```````!D6P``````
M``D````````````````````$````````````````````D`````$````"````
M``````!@0````````&````````"(/```````````````````"```````````
M`````````)@````!`````@````````"(G$```````(B<````````_```````
M``````````````0```````````````````"F`````0````(`````````B)U`
M``````"(G0```````#`&```````````````````(````````````````````
ML`````X````#`````````/"]0```````\*T````````(````````````````
M````"``````````(`````````+P````/`````P````````#XO4```````/BM
M````````"`````````````````````@`````````"`````````#(````!@``
M``,``````````+Y`````````K@```````/`!````````!@`````````(````
M`````!``````````T0````$````#`````````/"_0```````\*\````````0
M````````````````````"``````````(`````````-8````!`````P``````
M````P$````````"P``````````(```````````````````@`````````"```
M``````#?`````0````,``````````,)`````````L@```````!@`````````
M```````````(````````````````````Y0````@````#`````````"#"0```
M````&+(```````"($```````````````````(````````````````````.H`
M```!````,````````````````````!BR````````:```````````````````
M``$``````````0````````#S`````0```#````````````````````"`L@``
M`````-@,```````````````````!``````````$``````````0````,`````
M````````````````````6+\````````%`0```````````````````0``````
*````````````````
